;------------------------------------------------------------
;------------------------------------------------------------
;------------------------------------------------------------
;+
;
; @file_comments 
; Build a gif animation
;
; @categories Animated drawings.
;
; @param toto.gif {in}{required} It is the name of the gif file containing the animation.
;                         Comment: this file is placed in the directory defined by iodir.
;
; @uses common.pro
;
; @restrictions We use the Z buffer to go faster!.
;              So, if it failed in animgif, you have to do:
;              IDL> device, /close
;              IDL> set_plot, 'x'
;              IDL> retall
;
; @restrictions If we want to delete the @common,
;               we have to define manually the picture's size 
;               (variables xsize and ysize) just as iodir.
;
; @history Guillaume Roullet (grlod@ipsl.jussieu.fr)
;          Sebastien Masson (smasson@lodyc.jussieu.fr)
;          30/4/1999
;
; @version $Id$
;
;-
;------------------------------------------------------------
;------------------------------------------------------------
;------------------------------------------------------------
PRO animgif, nomfic
;
  compile_opt idl2, strictarrsubs
;
@common
;
;  It recuperates the color palette and put it in red, green, blue.
;
   tvlct,  rouge,vert,bleu,/get
;
;  It completes the current palette on 256 colors.
;
   red = [rouge, replicate(255, 256-n_elements(rouge))] 
   green = [vert, replicate(255, 256-n_elements(rouge))] 
   blue = [bleu, replicate(255, 256-n_elements(rouge))] 
;
; It rocks on the z device, allowing to create the picture without display it.
   thisOS = !VERSION.OS_FAMILY
   thisOS = STRMID(thisOS, 0, 3)
   thisOS = STRUPCASE(thisOS)
   set_plot, 'z'
; size of the picture (in pixel):
   xsize = 30*(min(page_size, max = ma)*key_portrait + ma*(1-key_portrait))
   ysize = 30*(min(page_size, max = ma)*(1-key_portrait) + ma*key_portrait)
   device, set_resolution = [xsize, ysize]
;
; Beginning of the gif file. Writing of an empty picture. 
;
   reinitplt
   plot, [0], [0], /nodata
   write_gif,iodir+nomfic,tvrd(),red, green, blue, /multiple
;
;
;----------------------------------------------------------------
; Beggining of the part we want to change.
;----------------------------------------------------------------
;
; Loop of picture's creation.
;
   calen = TIMEGEN(366, START=JULDAY(1,1,2000)) 
   debut = where(calen EQ 19810105)
   debut = where(calen EQ 19790105)
   debut = debut[0]
   if debut EQ -1 then begin
      device, /close
      CASE thisOS of
         'MAC': SET_PLOT, thisOS
         'WIN': SET_PLOT, thisOS
         ELSE: SET_PLOT, 'X'
      ENDCASE
      stop
   endif

   for i = 0, 73*15-1 do begin
;   for i = 0, 3*2-1 do begin
;   for i = 0, 73*2-1 do begin
;     print, 'Image numero : '+strtrim(i, 2)
      date = calen[debut+i]
      erase, 255
      plt, nlec('sst', date, 'ATF'), 19, 29, int = .5, /noerase
;      plt, nlec('sss', date, 'ATF'), label = 2, /noerase
;      plt, nlec('htoth', date, 'RE3')-nlec('hpycn', date, 'RE3'), 10, 60, int = 5, /inv, /noerase
;      domdef, 290,340,-5,15 
;      plt, norme(nlec('unsurf', date, 'RE3'), nlec('vnsurf', date, 'RE3')), 0, 1.2, int = .1, /noerase
;
;     Writing of the picture in the file .gif.
;
      write_gif,iodir+nomfic,tvrd(),red, green, blue, /multiple
   ENDFOR 
;----------------------------------------------------------------
; End of the part we want to change.
;----------------------------------------------------------------
;
; Closing of the file.
   write_gif,iodir+nomfic,/close 
; Rerock on terminal X mode.
;   device, /close
   CASE thisOS of
      'MAC': SET_PLOT, thisOS
      'WIN': SET_PLOT, thisOS
      ELSE: SET_PLOT, 'X'
   ENDCASE


   return
end
